// Copyright (c) 2021 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "libs.h"

// Display / Rendering
#include "display/animation/easing.h"
#include "display/animation/queue.h"
#include "display/animation/timeline.h"
#include "display/debug/grid.h"

#include "display/gui/bitmapfont.h"
#include "display/gui/font.h"

#include "display/camera.h"
#include "display/framebuffer.h"
#include "display/matrix.h"
#include "display/primitive.h"
#include "display/render.h"
#include "display/shader.h"
#include "display/spritebatch.h"
#include "display/texture.h"
#include "display/tileset.h"

// Game Engine
#include "engine/engine.h"

// Time Management
#include "epoch/epoch.h"

// File / Asset Management
#include "file/asset.h"
#include "file/csv.h"

// Game Logic
#include "game/game.h"

#include "game/dawn/dawngame.h"

#include "game/poker/pokergame.h"
#include "game/poker/pokerdiscussion.h"
#include "game/poker/pokergameassets.h"
#include "game/poker/pokerui.h"

// Player Input
#include "input/input.h"

// Locales
#include "locale/language.h"

// Poker Game Logic
#include "poker/bet.h"
#include "poker/card.h"
#include "poker/dealer.h"
#include "poker/player.h"
#include "poker/poker.h"
#include "poker/winner.h"

// User Interface Objects
#include "ui/frame.h"
#include "ui/label.h"

// Utility Objects
#include "util/array.h"
#include "util/list.h"
#include "util/math.h"
#include "util/rand.h"
#include "util/string.h"

// Visual Novel Objects
#include "vn/vncharacter.h"
#include "vn/vnconversation.h"
#include "vn/vnscene.h"
#include "vn/vntextbox.h"